@@ -1,4 +1,4 @@
-"coef.grm" <-
+`coef.grm` <-
 function (object, ...) {
     if (!inherits(object, "grm"))
         stop("Use only with 'grm' objects.\n")
