@@ -1,5 +1,5 @@
 `factor.scores.ltm` <-
-function (object, resp.patterns = NULL, method = c("EB", "MI", "Component"), B = 5, 
+function (object, resp.patterns = NULL, method = c("EB", "EAP", "MI", "Component"), B = 5, 
                                 robust.se = FALSE, ...) {
     if (!inherits(object, "ltm"))
         stop("Use only with 'ltm' objects.\n")
@@ -27,11 +27,12 @@ function (object, resp.patterns = NULL, method = c("EB", "MI", "Component"), B =
         if (factors == 2)
             res$z2 <- colSums(t(X) * betas[, 3])
     }
-    if (method == "EB" || method == "MI") {
+    if (method %in% c("EB", "EAP", "MI")) {
         environment(fscores.l) <- environment()
         res <- fscores.l(betas, X, method)
     }
-    out <- list(score.dat = res, method = method, B = B, call = object$call, resp.pats = !is.null(resp.patterns))
+    out <- list(score.dat = res, method = method, B = B, call = object$call, resp.pats = !is.null(resp.patterns),
+                coef = coef(object))
     class(out) <- "fscores"
     out
 }
