@@ -1,5 +1,5 @@
 `factor.scores.rasch` <-
-function (object, resp.patterns = NULL, method = c("EB", "MI"), B = 5, robust.se = FALSE, ...) {
+function (object, resp.patterns = NULL, method = c("EB", "EAP", "MI"), B = 5, robust.se = FALSE, ...) {
     if (!inherits(object, "rasch"))
         stop("Use only with 'rasch' objects.\n")
     betas <- object$coef
@@ -14,7 +14,8 @@ function (object, resp.patterns = NULL, method = c("EB", "MI"), B = 5, robust.se
     names(res)[1:p] <- rownames(betas)
     environment(fscores.r) <- environment()
     res <- fscores.r(betas, X, method)
-    out <- list(score.dat = res, method = method, B = B, call = object$call, resp.pats = !is.null(resp.patterns))
+    out <- list(score.dat = res, method = method, B = B, call = object$call, resp.pats = !is.null(resp.patterns),
+                coef = coef(object))
     class(out) <- "fscores"
     out
 }
