@@ -1,5 +1,5 @@
 `factor.scores.tpm` <-
-function (object, resp.patterns = NULL, method = c("EB", "MI"), B = 5, ...) {
+function (object, resp.patterns = NULL, method = c("EB", "EAP", "MI"), B = 5, ...) {
     if (!inherits(object, "tpm"))
         stop("Use only with 'tpm' objects.\n")
     thetas <- object$coef
@@ -8,13 +8,14 @@ function (object, resp.patterns = NULL, method = c("EB", "MI"), B = 5, ...) {
     nx <- nrow(X)
     p <- ncol(X)
     method <- match.arg(method)
-    vals <- lapply(1:ncol(X), function (i) c(0,1))
+    vals <- lapply(1:ncol(X), function (i) c(0, 1))
     Obs <- observedFreqs(object, X, vals)
     res <- data.frame(X, Obs = Obs, Exp = fits[, ncol(fits)])
     names(res)[1:p] <- rownames(thetas)
     environment(fscores.t) <- environment()
     res <- fscores.t(thetas, X, method)
-    out <- list(score.dat = res, method = method, B = B, call = object$call, resp.pats = !is.null(resp.patterns))
+    out <- list(score.dat = res, method = method, B = B, call = object$call, resp.pats = !is.null(resp.patterns),
+                coef = coef(object))
     class(out) <- "fscores"
     out
 }
