@@ -34,6 +34,22 @@ function (betas, X, method) {
             res$se.z2 <- se.ML[, 2]
         }
     }
+    if (method == "EAP") {
+        Z <- object$GH$Z
+        GHw <- object$GH$GHw
+        pr <- probs(Z %*% t(betas))
+        if (any(na.ind <- is.na(X)))
+            X[na.ind] <- 0        
+        p.xz <- exp(X %*% t(log(pr)) + (1 - X) %*% t(log(1 - pr)))
+        p.x <- c(p.xz %*% GHw)
+        p.zx <- p.xz / p.x
+        res$z1 <- c(p.zx %*% (Z[, 2] * GHw))
+        res$se.z1 <- sqrt(c(p.zx %*% (Z[, 2] * Z[, 2] * GHw)) - res$z1^2)
+        if (object$ltst$factors > 1){
+            res$z2 <- c(p.zx %*% (Z[, 3] * GHw))
+            res$se.z2 <- sqrt(c(p.zx %*% (Z[, 3] * Z[, 3] * GHw)) - res$z2^2)
+        }   
+    }
     if (method == "MI") {
         constraint <- object$constraint
         if (!is.null(constraint))
