@@ -19,6 +19,18 @@ function (betas, X, method) {
         res$z1 <- scores.ML
         res$se.z1 <- sqrt(hes.ML)
     }
+    if (method == "EAP") {
+        Z <- object$GH$Z
+        GHw <- object$GH$GHw
+        pr <- probs(Z %*% t(betas))
+        if (any(na.ind <- is.na(X)))
+            X[na.ind] <- 0
+        p.xz <- exp(X %*% t(log(pr)) + (1 - X) %*% t(log(1 - pr)))
+        p.x <- c(p.xz %*% GHw)
+        p.zx <- p.xz / p.x
+        res$z1 <- c(p.zx %*% (Z[, 2] * GHw))
+        res$se.z1 <- sqrt(c(p.zx %*% (Z[, 2] * Z[, 2] * GHw)) - res$z1^2)
+    }
     if (method == "MI") {
         constraint <- object$constraint
         betas <- c(betas[, 1], betas[1, 2])
